#
# spec file for package python-rsa
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests

%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-rsa
Version:        3.4.2
Release:        lp152.4.3.1
Url:            http://stuvel.eu/rsa
Summary:        Pure-Python RSA Implementation
License:        Apache-2.0
Group:          Development/Languages/Python
Source:         https://files.pythonhosted.org/packages/source/r/rsa/rsa-%{version}.tar.gz
Patch0:         cve_2020-13757.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module pyasn1 >= 0.1.3}
%if %{with tests}
BuildRequires:  %{python_module nose}
%endif
Requires:       python-pyasn1 >= 0.1.3
BuildArch:      noarch
Requires(pre):    coreutils
Requires(post):   update-alternatives
Requires(preun):  update-alternatives
%python_subpackages

%description
Python-RSA is a pure-Python RSA implementation. It supports encryption and
decryption, signing and verifying signatures, and key generation according to
PKCS#1 version 1.5.

%prep
%setup -q -n rsa-%{version}
%patch0

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/pyrsa-priv2pub
%python_clone -a %{buildroot}%{_bindir}/pyrsa-decrypt
%python_clone -a %{buildroot}%{_bindir}/pyrsa-decrypt-bigfile
%python_clone -a %{buildroot}%{_bindir}/pyrsa-encrypt
%python_clone -a %{buildroot}%{_bindir}/pyrsa-encrypt-bigfile
%python_clone -a %{buildroot}%{_bindir}/pyrsa-keygen
%python_clone -a %{buildroot}%{_bindir}/pyrsa-sign
%python_clone -a %{buildroot}%{_bindir}/pyrsa-verify

%post
%{python_install_alternative pyrsa-priv2pub pyrsa-decrypt pyrsa-decrypt-bigfile pyrsa-encrypt pyrsa-encrypt-bigfile pyrsa-keygen pyrsa-sign pyrsa-verify}

%preun
%python_uninstall_alternative pyrsa-priv2pub

%if %{with tests}
%check
%python_exec setup.py test
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc CHANGELOG.txt LICENSE README.md
%python_alternative %{_bindir}/pyrsa-decrypt
%python_alternative %{_bindir}/pyrsa-decrypt-bigfile
%python_alternative %{_bindir}/pyrsa-encrypt
%python_alternative %{_bindir}/pyrsa-encrypt-bigfile
%python_alternative %{_bindir}/pyrsa-keygen
%python_alternative %{_bindir}/pyrsa-priv2pub
%python_alternative %{_bindir}/pyrsa-sign
%python_alternative %{_bindir}/pyrsa-verify
%{python_sitelib}/*

%changelog
* Fri Jun 11 2021 Robert Schweikert <rjschwei@suse.com>
- Add cve_2020-13757.patch (CVE-2020-13757 bsc#1172389)
  + Handle leading '\0' bytes during decryption of ciphertext
* Mon May  1 2017 toddrme2178@gmail.com
- Update to Version 3.4.2
  * Fixed dates in CHANGELOG.txt
- Update to Version 3.4.1
  * Included tests/private.pem in MANIFEST.in
  * Included README.md and CHANGELOG.txt in MANIFEST.in
- Update to Version 3.4
  * Moved development to Github: https://github.com/sybrenstuvel/python-rsa
  * Solved side-channel vulnerability by implementing blinding, fixes #19
  * Deprecated the VARBLOCK format and rsa.bigfile module due to security issues, see
    https://github.com/sybrenstuvel/python-rsa/issues/13
  * Integration with Travis-CI, Coveralls and Code Climate
  * Deprecated the old rsa._version133 and rsa._version200 submodules, they will be
    completely removed in version 4.0.
  * Add an 'exponent' argument to key.newkeys()
  * Switched from Solovay-Strassen to Miller-Rabin primality testing, to
    comply with NIST FIPS 186-4 as probabilistic primality test
    (Appendix C, subsection C.3):
  * Fixed bugs #12, #14, #27, #30, #49
- Update to Version 3.3
  * Thanks to Filippo Valsorda: Fix BB'06 attack in verify() by
    switching from parsing to comparison.
  * Simplified Tox configuration and dropped Python 3.2 support. The
    coverage package uses a u'' prefix, which was reintroduced in 3.3
    for ease of porting.
- Update to Version 3.2.3
  * Added character encoding markers for Python 2.x
- Update to Version 3.2.1
  * Added per-file licenses
  * Added support for wheel packages
  * Made example code more consistent and up to date with Python 3.4
- Update to Version 3.2
  * Mentioned support for Python 3 in setup.py
- Implement single-spec version.
- Fix source URL.
- Remove cve_2016-1494.diff, fixed in latest version.
* Tue Jan  5 2016 rjschwei@suse.com
- Fix CVE 2016-1494 (bsc#960680)
  - Add patch cve_2016-1494.diff
* Tue Dec  1 2015 rjschwei@suse.com
- Include version 3.1.4 in SLE 12 (FATE#319904, bsc#954690)
* Fri Nov 20 2015 p.drouand@gmail.com
- Fix coreutils requirement
* Wed Sep 23 2015 rjschwei@suse.com
- require coreutils (bsc#935595)
  + %%pre section uses rm which is part of coreutils package
* Tue May 12 2015 benoit.monin@gmx.fr
- update to version 3.1.4:
  * no changelog available
- add test dependency python-unittest2
- fix update-alternatives
- run the tests with run_tests.py
- add README.rst to the package documentation
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Fri Oct 11 2013 p.drouand@gmail.com
- Update to version 3.1.2
  + No changelog available
- Replace python-distribute with python-setuptools BuildRequires
- Remove rsa-use-system-setuptools.patch; merged upstream
- Implement update-alternatives
* Mon Aug 12 2013 speilicke@suse.com
- Add rsa-use-system-setuptools.patch
* Fri Nov 23 2012 speilicke@suse.com
- Update to version 3.1.1:
  + Upstream provides no changelog
* Fri May 18 2012 jfunk@funktronics.ca
- Initial release
